﻿using Syncfusion.SfChart.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;

namespace LineTest
{
    public class ChartSample : ContentPage
    {
        StackLayout layout;
        SfChart chart;
        FastLineSeries series;

        ObservableCollection<ChartDataPoint> datas;
        public ChartSample()
        {
            layout = new StackLayout();

            chart = EmptyLinearChartBuilder(false, "Line Series");
            chart.VerticalOptions = LayoutOptions.FillAndExpand;
            chart.HorizontalOptions = LayoutOptions.FillAndExpand;

            series = new FastLineSeries();            
            chart.Series.Add(series);

            Button button = new Button();
            button.Text = "Reload";
            button.Clicked += Button_Clicked;

            layout.Children.Add(chart);
            layout.Children.Add(button);
            Content = layout;
        }

        ObservableCollection<ChartDataPoint> DataPoints()
        {
            datas = new ObservableCollection<ChartDataPoint>();
            datas.Add(new ChartDataPoint("Jan", 20));
            datas.Add(new ChartDataPoint("Feb", 30));
            datas.Add(new ChartDataPoint("Mar", 25));
            datas.Add(new ChartDataPoint("Apr", 40));
            datas.Add(new ChartDataPoint("May", 15));
            return datas;
        }

        private void Button_Clicked(object sender, EventArgs e)
        {
            series.ItemsSource = DataPoints();
        }

        public SfChart EmptyLinearChartBuilder(bool hasLegend, String isVisibileProperty)
        {
            NumericalAxis secondaryAxis = new NumericalAxis
            {
                RangePadding = NumericalPadding.Round,
                Maximum = 110,
                Minimum = -5,
                MajorTickStyle = new ChartAxisTickStyle
                {
                    TickSize = 3
                },
                EdgeLabelsDrawingMode = EdgeLabelsDrawingMode.Shift
            };

            var chart = new SfChart
            {
                VerticalOptions = LayoutOptions.FillAndExpand,
                HorizontalOptions = LayoutOptions.FillAndExpand,
                PrimaryAxis = new CategoryAxis
                {
                    MaximumLabels = 3,
                    OpposedPosition = true,
                    LabelPlacement = LabelPlacement.BetweenTicks,
                    LabelStyle = new ChartAxisLabelStyle
                    {
                        LabelsPosition = AxisElementPosition.Inside
                    },
                    EdgeLabelsDrawingMode = EdgeLabelsDrawingMode.Shift,
                    MajorTickStyle = new ChartAxisTickStyle
                    {
                        TickSize = 0
                    },
                    ShowMajorGridLines = false

                },
                SecondaryAxis = secondaryAxis
            };

            if (hasLegend)
            {
                chart.Legend = new ChartLegend();
                chart.Legend.DockPosition = LegendPlacement.Bottom;
                chart.Legend.IconHeight = 20;
                chart.Legend.IconWidth = 20;
                chart.Legend.IsVisible = true;
                chart.Legend.IsIconVisible = true;
            }

            if (!String.IsNullOrEmpty(isVisibileProperty))
            {
                NumericalStripLine noData = new NumericalStripLine
                {
                    Text = isVisibileProperty,
                    Start = -5,
                    Width = 110,
                    FillColor = Color.Transparent
                };
                noData.SetBinding(NumericalStripLine.IsVisibleProperty, new Binding(isVisibileProperty));
                secondaryAxis.StripLines.Add(noData);
            }
            return chart;
        }
    }
}
